PALM-meteo: palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform Class Reference
Inheritance diagram for palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform:
[legend]
Collaboration diagram for palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform:
[legend]

## Public Member Functions
def | __init__ (self, ncf)
def | verify (self, ncf)
Public Member Functions inherited from palmmeteo_stdplugins.wrf_utils.WRFCoordTransform
def | __init__ (self, ncf)
def | latlon_to_ji (self, lat, lon)
def | ji_to_latlon (self, j, i)
def | verify (self, ncf)

## Public Attributes
| latlon_sphere
| lambert_grid
| dx
| dy
| nx
| ny
| i0_x
| j0_y
Public Attributes inherited from palmmeteo_stdplugins.wrf_utils.WRFCoordTransform
| latlon_sphere
| lambert_grid
| dx
| dy
| nx
| ny
| i0_x
| j0_y

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.__init__ | ( |  | self,
|  |  | ncf
| ) |  |

Reimplemented from palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.

## Member Function Documentation

## ◆ verify()

def palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.verify | ( |  | self,
|  |  | ncf
| ) |  |

Reimplemented from palmmeteo_stdplugins.wrf_utils.WRFCoordTransform.

## Member Data Documentation

## ◆ dx

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.dx

## ◆ dy

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.dy

## ◆ i0_x

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.i0_x

## ◆ j0_y

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.j0_y

## ◆ lambert_grid

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.lambert_grid

## ◆ latlon_sphere

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.latlon_sphere

## ◆ nx

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.nx

## ◆ ny

palmmeteo_stdplugins.wrf_utils.CAMxCoordTransform.ny

The documentation for this class was generated from the following file:

- palmmeteo_stdplugins/wrf_utils.py